@@ -33,11 +33,12 @@ class SolveNewmark(_BaseODE):
     (coupled).
 
     Unlike :class:`SolveUnc` and :class:`SolveExp2`, this solver can
-    handle a singular mass matrix. For most (all?) other cases, the
-    other two solvers are preferred since they are exact assuming
-    piece-wise linear forces (if `order` is 1) or piece-wise constant
-    forces (if `order` is 0). :class:`SolveUnc` is also very likely
-    significantly faster for most problems.
+    handle a singular mass matrix. It can also handle non-linear force
+    terms very well. For most (all?) other cases, the other two
+    solvers are preferred since they are exact assuming piece-wise
+    linear forces (if `order` is 1) or piece-wise constant forces (if
+    `order` is 0). :class:`SolveUnc` is also very likely significantly
+    faster for most problems.
 
     The equations for the non-residual equations are:
 
@@ -162,8 +163,8 @@ class SolveNewmark(_BaseODE):
         Plot the four accelerations:
 
         >>> import matplotlib.pyplot as plt
-        >>> fig = plt.figure('Example', figsize=[8, 8])
-        >>> fig.clf()
+        >>> fig = plt.figure('Example', figsize=[8, 8], clear=True,
+        ...                  layout='constrained')
         >>> labels = ['Rigid-body', 'Underdamped',
         ...           'Critically Damped', 'Overdamped']
         >>> for j, name in zip(range(4), labels):
@@ -175,7 +176,6 @@ class SolveNewmark(_BaseODE):
         ...     _ = plt.xlabel('Time (s)')
         ...     if j == 0:
         ...         _ = plt.legend(loc='best')
-        >>> fig.tight_layout()
     """
 
     def __init__(self, m, b, k, h=None, rf=None):
@@ -210,6 +210,9 @@ class SolveNewmark(_BaseODE):
         m             mass for the non-rf DOF (or None for identity)
         b             damping for the non-rf DOF
         k             stiffness for the non-rf DOF
+        m_orig        original mass
+        b_orig        original damping
+        k_orig        original stiffness
         h             time step
         rb            np.array([])
         el            index vector or slice for the non-rf DOF
@@ -419,7 +422,7 @@ class SolveNewmark(_BaseODE):
                        user-supplied function `func_i` to apply the
                        transform internally, is for efficiency: the
                        relatively expensive operation of:
-                       :math:`A^{-1} T_i` is done now, outside the
+                       :math:`A^{-1} T_i` is precomputed outside the
                        integration loop. The matrix :math:`A` is
                        defined in :class:`SolveNewmark`.
 
@@ -435,10 +438,16 @@ class SolveNewmark(_BaseODE):
                    T_1 @ func_1(d, j, h, **optargs_1) +
                    ...)
 
-        That term is used to compute the ``j+1``'th displacement; see
-        equation in :class:`SolveNewmark`. That is appropriate because
-        of the nature of the central finite difference formulae used
-        in the Newmark-Beta formation.
+        That term is used to compute the ``j+1``'th displacement. That
+        is appropriate because of the nature of the central finite
+        difference formulae used in the Newmark-Beta formation. For
+        reference, here is the equation (copied from
+        :class:`SolveNewmark`):
+
+        .. math::
+            A u_{n+2} = \frac{1}{3}
+            \left ( F_{n+2} + F_{n+1} + F_{n} \right ) + N_{n+1} +
+            A_1 u_{n+1} + A_0 u_{n}
 
         The solution namespace returned by :func:`tsolve` will contain
         the outputs of each user defined function in the dictionary
@@ -510,7 +519,7 @@ class SolveNewmark(_BaseODE):
             ...                    [6,    1000.],
             ...                    [10,   1500.]])
             >>>
-            >>> # force transforming lookup value to forces on the
+            >>> # for transforming lookup value to forces on the
             >>> # masses:
             >>> Tfrc = np.array([[-1.], [1.]])
             >>>
@@ -549,8 +558,8 @@ class SolveNewmark(_BaseODE):
             >>> sol2 = ts2.finalize()
             >>>
             >>> # plot results:
-            >>> _ = plt.figure('Example', figsize=(8, 8))
-            >>> plt.clf()
+            >>> _ = plt.figure('Example', figsize=(8, 8), clear=True,
+            ...                layout='constrained')
             >>>
             >>> _ = plt.subplot(311)
             >>> _ = plt.plot(t, sol.d.T)
@@ -579,7 +588,6 @@ class SolveNewmark(_BaseODE):
             >>> _ = plt.xlabel('Time (s)')
             >>> _ = plt.ylabel('Force')
             >>> _ = plt.legend()
-            >>> _ = plt.tight_layout()
         """
         # apply inv(A) to the transforms while making new dict:
         nl_dct = {}
