@@ -66,7 +66,7 @@ class PP:
         >>> from types import SimpleNamespace
         >>> from pyyeti.pp import PP
         >>> r = np.arange(4, dtype=np.int16)
-        >>> s = np.random.randn(4, 4, 4)
+        >>> s = np.zeros((4, 4, 4))
         >>> t = np.array(9, dtype=np.uint8)
         >>> d = {'asdf': 4,
         ...      '34': 'value',
@@ -117,7 +117,7 @@ class PP:
         ...     a = 9
         ...     b = {'variable': [1, 2, 3]}
         >>> PP(A, 2)       # doctest: +ELLIPSIS
-        <class 'A'>[n=6]
+        <class 'A'>[n=...]
             .a: 9
             .b: <class 'dict'>[n=1]
                 'variable': [n=3]: [1, 2, 3]
@@ -289,4 +289,5 @@ class PP:
         self.s = s
         self.output = "".join(s)
         for line in self.output.split("\n"):
-            print(repr(line)[1:-1])
+            print(line)
+            # print(repr(line)[1:-1])
